@@ -20,17 +20,20 @@ var fscan = require('./../common/fscan');
 var cookieParser = require('cookie-parser');
 const work_dir = process.cwd();
 const m_dir = "/app/modules";
+const authenticate = require('../common/authenticate');
 
 module.exports = function (nylon) {
     var logger = nylon.logger;
     logger.info("nylon Server run at env : " + process.env.NODE_ENV);
     var app = express();
+
     app.use(cookieParser());
     /** load express module */
 
 
     app.nylon = nylon;
     // app.nylon.r=db;
+    app.authenticate=authenticate;
 
     console.log("work_dir::" + nylon.work_dir);
 
